FlutterBackgroundVideoRecorder class

Properties

hashCode → int
The hash code for this object.
no setterinherited
recorderState → Stream<int>
Get current state of video recorder as a stream
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

getVideoRecordingStatus() → Future<int?>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
startVideoRecording({required String folderName, required CameraFacing cameraFacing, required String notificationTitle, required String notificationText, bool showToast = false}) → Future<bool?>
stopVideoRecording() → Future<String?>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited